@@ -445,10 +445,10 @@ class SyncIOClient(MongoClient):
         assert collection, "collection must be of type str"
         query.update({field: {'$exists': False}})
         if data:
-            records = self.GET(collection, query=query, fields={
+            records = self.GET(collection, query, fields={
                 data: True}, empty=[])
         else:
-            records = self.GET(collection, query=query, fields={
+            records = self.GET(collection, query, fields={
                 '_id': True}, empty=[])
 
         for record in records:
@@ -468,7 +468,7 @@ class SyncIOClient(MongoClient):
         collection = collection or self._DEFAULT_COLLECTION
         assert collection, "collection must be of type str"
         query.update({field: {'$exists': True}})
-        records = self.GET(collection, query=query, distinct=True)
+        records = self.GET(collection, query, distinct=True)
 
         for record in records:
             self.PATCH(collection, record, {"$unset": {field: ""}})
@@ -905,7 +905,7 @@ class SyncIODoc(SyncIOClient):
             field: True
             })
 
-        record = self.GET(collection, query={field: value}, fields=additional, one=True, empty={})
+        record = self.GET(collection, {field: value}, fields=additional, one=True, empty={})
         assert record, 'Error: No record found'
 
         record['key'] = field
@@ -918,7 +918,7 @@ class SyncIODoc(SyncIOClient):
         # If _id specified on init, load actual record versus blank template
         if _id:
             if self._DOC_ID:
-                self.RECORD = self.GET(self._DOC_TYPE, query={self._DOC_ID: _id}, one=True)
+                self.RECORD = self.GET(self._DOC_TYPE, {self._DOC_ID: _id}, one=True)
             else:
                 self.RECORD = self.GET(self._DOC_TYPE, _id)
         else:
@@ -940,14 +940,14 @@ class SyncIODoc(SyncIOClient):
         else:
             if self._DOC_ID:
                 return StandardResponse(
-                            data=self._p_r(self.GET(self._DOC_TYPE, query={self._DOC_ID: _id}, one=True, empty={})),
+                            data=self._p_r(self.GET(self._DOC_TYPE, {self._DOC_ID: _id}, one=True, empty={})),
                             details={
                         "unique_id": self._DOC_ID
                         }
                     )
             else:
                 return StandardResponse(
-                            data=self._p_r(self.GET(self._DOC_TYPE, query={"_id": _id}, one=True, empty={})),
+                            data=self._p_r(self.GET(self._DOC_TYPE, {"_id": _id}, one=True, empty={})),
                             details={
                         "unique_id": self._DOC_ID
                         }
@@ -967,7 +967,7 @@ class SyncIODoc(SyncIOClient):
     def id(self):
         return self.RECORD.get(self._DOC_ID, None)
 
-    def create(self, save=False, trigger=None, template="{total}", query={}, **kwargs):
+    def create(self, save:bool=False, trigger=None, template:str="{total}", query:dict={}, **kwargs):
         assert self.RECORD.get('_id') is None, """Cannot use create method on
  an existing record. Use patch method instead."""
 
@@ -981,7 +981,7 @@ class SyncIODoc(SyncIOClient):
         else:
             self.RECORD.update(kwargs)
 
-        kwargs['total'] = str(self.GET(self._DOC_TYPE, query=query).count() + 1).zfill(6)
+        kwargs['total'] = str(self.GET(self._DOC_TYPE, query).count() + 1).zfill(6)
 
         if self._DOC_ID and not self.RECORD.get(self._DOC_ID):
             self.RECORD[self._DOC_ID] = self._generate_unique_id(template=template, **kwargs)
@@ -1040,7 +1040,7 @@ class SyncIODoc(SyncIOClient):
                 }
             }
 
-    def increment(self, query={}, **kwargs):
+    def increment(self, query:dict={}, **kwargs):
         assert self.RECORD.get('_id'), """Cannot use increment method on
  a non-existing record. Use create method instead."""
 
@@ -1065,7 +1065,7 @@ class SyncIODoc(SyncIOClient):
                 }
             }
 
-    def update(self, query={}, **kwargs):
+    def update(self, query:dict={}, **kwargs):
         assert self.RECORD.get('_id'), """Cannot use increment method on
  a non-existing record. Use create method instead."""
 
